@@ -63,6 +63,7 @@ async def index(request: web.Request) -> web.Response:
     if (
         not token
         or not redirect_to
+        # If host contains "serve-": redirect_to will equal the host, instead of a key in `path`
         or ("serve" not in host and redirect_to not in path)
     ):
         return web.Response(
@@ -102,6 +103,12 @@ async def authorize(request: web.Request) -> web.Response:
     cookies = request.cookies
     if cookies.get("anyscale-token") == request.config_dict["auth_token"]:
         return web.Response(text="Authorized", status=200)
+    headers = request.headers
+    if (
+        headers.get("Authorization") == f"Bearer {request.config_dict['auth_token']}"
+        or headers.get("Authorization") == f"bearer {request.config_dict['auth_token']}"
+    ):
+        return web.Response(text="Authorized", status=200)
     unauthorized_message = (
         "Unauthorized. Please navigate to this resource through the cluster's page in the Anyscale "
         "product. Doing so will automatically authorize this request from a web browser. Please "
