@@ -99,7 +99,7 @@ class AuthenticationBlock:
         api_instance = openapi_client.DefaultApi(api_client)
         return api_instance
 
-    def _instantiate_anyscale_client(self, use_asyncio=False,) -> AnyscaleApi:
+    def _instantiate_anyscale_client(self, use_asyncio: bool = False) -> AnyscaleApi:
         """
         Instantiates client to interact with our externalized APIs
 
@@ -214,7 +214,7 @@ def get_auth_api_client(
     use_asyncio: bool = False,
     validate_credentials: bool = True,
     log_output: bool = True,
-):
+) -> AuthenticationBlock:
     """
     Function to get global AuthenticationBlock object. The AuthenticationBlock will only be
     instantiated once with the passed parameters from the first call to get_auth_api_client
