@@ -103,6 +103,7 @@ def cloud_set_default(
 @click.option(
     "--yes", "-y", is_flag=True, default=False, help="Don't ask for confirmation."
 )
+@click.option("--legacy/--no-legacy", default=True, hidden=True)
 @click.option(
     "--gcp-folder-id",
     help="Folder ID where the 'Anyscale'  folder will be created.",
@@ -126,6 +127,7 @@ def setup_cloud(
     region: str,
     name: str,
     yes: bool,
+    legacy: bool,
     gcp_folder_id: Optional[int],
     vpc_peering_ip_range: Optional[str],
     vpc_peering_target_project_id: Optional[str],
@@ -133,6 +135,7 @@ def setup_cloud(
 ) -> None:
     CloudController().setup_cloud(
         is_aioa=bring_cloud_account == "no",
+        is_k8s=not legacy,
         provider=provider,
         region=region,
         name=name,
