@@ -1,15 +1,26 @@
+from abc import ABC, abstractmethod
 from datetime import datetime
 import os
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Union
+import time
+from typing import Any, cast, Dict, List, Optional, Tuple, Type, Union
 
 import click
 from pydantic import BaseModel, Field, root_validator
+import requests
+from requests.adapters import HTTPAdapter
 import tabulate
+from urllib3 import Retry
 import yaml
 
 from anyscale.cli_logger import BlockLogger
-from anyscale.client.openapi_client import CreateProductionJob, ProductionJobConfig
+from anyscale.client.openapi_client import (
+    CreateProductionJob,
+    DecoratedProductionJob,
+    HaJobStates,
+    JobsLogsQueryInfo,
+    ProductionJobConfig,
+)
 from anyscale.cluster_compute import (
     get_cluster_compute_from_name,
     get_default_cluster_compute,
@@ -26,7 +37,7 @@ from anyscale.project import (
     get_project_id,
     ProjectDefinition,
 )
-from anyscale.util import get_endpoint
+from anyscale.util import get_endpoint, PROJECT_NAME_ENV_VAR
 
 
 log = BlockLogger()
@@ -176,7 +187,11 @@ class JobConfig(BaseModel):
             raise click.ClickException(
                 "Only one of `project_id` or `project` can be provided in the job config file. "
             )
-        if project_name:
+        project_name_env_var = os.environ.get(PROJECT_NAME_ENV_VAR)
+        if project_name_env_var:
+            # Get project from environment variable regardless of if is provided in config
+            values["project_id"] = get_proj_id_from_name(project_name_env_var)
+        elif project_name:
             values["project_id"] = get_proj_id_from_name(project_name)
         return values
 
@@ -270,6 +285,63 @@ class JobConfig(BaseModel):
         return values
 
 
+class LogProvider(ABC):
+    @abstractmethod
+    def __init__(self, dns_name: str, anyscale_token: str, query: str) -> None:
+        pass
+
+    @abstractmethod
+    def query(
+        self, start_timestamp_ns: int, end_timestamp_ns: int
+    ) -> List[Tuple[int, str]]:
+        """Query logs for a time range, return list of (timestamp_ns, log_line)."""
+
+
+class LokiLogProvider(LogProvider):
+    def __init__(self, dns_name: str, anyscale_token: str, query: str) -> None:
+        # https://grafana.com/docs/loki/latest/api/#get-lokiapiv1query_range
+        self.url = f"https://{dns_name}/loki/api/v1/query_range"
+        self.params = {
+            "token": anyscale_token,
+            "query": query,
+            "limit": 1000,
+            "start": 0,
+            "end": int(time.time() * 1e9),
+            "direction": "forward",
+        }
+
+        self.session = requests.Session()
+        self.session.mount(
+            "https://",
+            HTTPAdapter(
+                max_retries=Retry(total=10, backoff_factor=0.1, allowed_methods=["GET"])
+            ),
+        )
+
+    def query(
+        self, start_timestamp_ns: int, end_timestamp_ns: int
+    ) -> List[Tuple[int, str]]:
+        self.params["start"] = start_timestamp_ns
+        self.params["end"] = end_timestamp_ns
+
+        resp = self.session.get(self.url, params=self.params)
+        resp.raise_for_status()
+
+        resp_data = resp.json()
+        if resp_data["status"] != "success":
+            raise click.ClickException("Querying Anyscale log endpoint failed.")
+        if resp_data["data"]["resultType"] != "streams":
+            raise click.ClickException("Invalid metrics type.")
+
+        lines = []
+        for log_chunk in resp_data["data"]["result"]:
+            # TODO(simon): potentially annotate the log with the log_chunk["stream"] metadata
+            for timestamp, line in log_chunk["values"]:
+                lines.append((int(timestamp), line))
+
+        return lines
+
+
 class JobController(BaseController):
     def __init__(
         self, log: BlockLogger = BlockLogger(), initialize_auth_api_client: bool = True
@@ -291,12 +363,20 @@ class JobController(BaseController):
             if root_dir is not None:
                 project_definition = ProjectDefinition(root_dir)
                 project_id = get_project_id(project_definition.root)
+                project_name = self.anyscale_api_client.get_project(
+                    project_id
+                ).result.name
+                self.log.warning(
+                    ".anyscale.yaml has been detected in this project directory. The functionality of "
+                    "using this file to select the project has been deprecated, and will be removed "
+                    f"in April 2022. Please instead specify `project_id: {project_id}` in the job config file. "
+                    "The project name can also be specified by setting the environment variable "
+                    f'`{PROJECT_NAME_ENV_VAR}="{project_name}"`.'
+                )
             else:
                 default_project = self.anyscale_api_client.get_default_project().result
                 project_id = default_project.id
-                self.log.info(
-                    f"No project context detected, so using default project {project_id}."
-                )
+                self.log.info("No project specified. Continuing without a project.")
 
         config_object = ProductionJobConfig(
             entrypoint=job_config.entrypoint,
@@ -325,6 +405,9 @@ class JobController(BaseController):
         self.log.info(
             f"Query the status of the job with `anyscale job list --job-id {job.id}`."
         )
+        self.log.info(
+            f"Get the logs for the job with `anyscale job logs --job-id {job.id} --follow`."
+        )
         self.log.info(f'View the job in the UI at {get_endpoint(f"/jobs/{job.id}")}.')
 
     def _read_job_config(self, job_config_file: str) -> JobConfig:
@@ -445,32 +528,12 @@ class JobController(BaseController):
         entities is currently the same.
         """
         entity_type = "service" if is_service else "job"
-        if job_id is not None:
-            job = self.api_client.terminate_job_api_v2_decorated_ha_jobs_production_job_id_terminate_post(
-                job_id
-            ).result
-        elif job_name is not None:
-            jobs_resp = self.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get(
-                name=job_name, type_filter="SERVICE" if is_service else "BATCH_JOB",
-            ).results
-            if len(jobs_resp) == 0:
-                raise click.ClickException(
-                    f"No {entity_type} found with name {job_name}. Please either pass `--id` or list the "
-                    f"available {entity_type}s with `anyscale {entity_type} list`."
-                )
-            elif len(jobs_resp) > 1:
-                raise click.ClickException(
-                    f"Multiple {entity_type}s found with name {job_name}. Please specify the `--id` instead."
-                )
-            else:
-                job = self.api_client.terminate_job_api_v2_decorated_ha_jobs_production_job_id_terminate_post(
-                    jobs_resp[0].id
-                ).result
-        else:
-            raise click.ClickException(
-                f"Either `--id` or `--name` must be passed in to terminate a {entity_type}."
-            )
-
+        job_resp: DecoratedProductionJob = self._resolve_job_object(
+            job_id, job_name, entity_type
+        )
+        job = self.api_client.terminate_job_api_v2_decorated_ha_jobs_production_job_id_terminate_post(
+            job_resp.id
+        ).result
         self.log.info(f"{entity_type.capitalize()} {job.id} has begun terminating...")
         self.log.info(
             f" Current state of {entity_type}: {job.state.current_state}. Goal state of {entity_type}: {job.state.goal_state}"
@@ -478,3 +541,99 @@ class JobController(BaseController):
         self.log.info(
             f"Query the status of the {entity_type} with `anyscale {entity_type} list --{entity_type}-id {job.id}`."
         )
+
+    def _resolve_job_object(
+        self, job_id: Optional[str], job_name: Optional[str], entity_type: str = "job"
+    ) -> DecoratedProductionJob:
+        """Given job_id or job_name, retrieve decorated ha job spec"""
+        if job_id is None and job_name is None:
+            raise click.ClickException(
+                f"Either `--id` or `--name` must be passed in for {entity_type}."
+            )
+        if job_id is None:
+            jobs_resp = self.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get(
+                name=job_name,
+                type_filter="BATCH_JOB" if entity_type == "job" else "SERVICE",
+            ).results
+            if len(jobs_resp) == 0:
+                raise click.ClickException(
+                    f"No {entity_type} found with name {job_name}. Please either pass `--id` or list the "
+                    f"available {entity_type}s with `anyscale {entity_type} list`."
+                )
+            if len(jobs_resp) > 1:
+                raise click.ClickException(
+                    f"Multiple {entity_type}s found with name {job_name}. Please specify the `--id` instead."
+                )
+            job_id = jobs_resp[0].id
+        jobs_resp = self.api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get(
+            production_job_id=job_id
+        ).result
+        return jobs_resp
+
+    def _wait_for_a_job_run(self, job_id: str) -> str:
+        """Given job_id, wait until there is a job run on a cluster."""
+        last_job_run_id = None
+        terminal_state = {
+            HaJobStates.SUCCESS,
+            HaJobStates.TERMINATED,
+            HaJobStates.BROKEN,
+            HaJobStates.OUT_OF_RETRIES,
+        }
+        while last_job_run_id is None:
+            job_object = self.api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get(
+                production_job_id=job_id
+            ).result
+            job_state = job_object.state.current_state
+            last_job_run_id = job_object.last_job_run_id
+            if job_state in terminal_state and last_job_run_id is None:
+                raise click.ClickException(
+                    f"Can't find latest job run for {job_state} job."
+                )
+            if last_job_run_id is None:
+                self.log.info(f"Waiting for a job run, current state is {job_state}.")
+                time.sleep(5)
+        return last_job_run_id
+
+    def logs(
+        self,
+        job_id: Optional[str],
+        job_name: Optional[str],
+        should_follow: bool = False,
+        log_provider_cls: Type[LogProvider] = LokiLogProvider,
+    ) -> None:
+        job_id = self._resolve_job_object(job_id, job_name).id
+        self._wait_for_a_job_run(cast(str, job_id))
+
+        # TODO(simon): implement ability to look through logs from previous tries
+        log_info: JobsLogsQueryInfo = self.api_client.get_job_logs_query_info_api_v2_decorated_ha_jobs_production_job_id_logs_query_get(
+            production_job_id=job_id
+        ).result
+
+        log_provider = log_provider_cls(
+            dns_name=log_info.loki_dns_name,
+            anyscale_token=log_info.access_token,
+            query=log_info.loki_query,
+        )
+
+        start_timestamp_ns = 0
+        end_timestamp_ns = int(time.time() * 1e9)
+        while True:
+            lines = log_provider.query(start_timestamp_ns, end_timestamp_ns)
+
+            for time_stamp, line in lines:
+                # Update the start timestamp in case we are following or paginated.
+                start_timestamp_ns = time_stamp
+                print(line)
+
+            # No log entry for our time range.
+            if len(lines) == 0:
+                if should_follow:
+                    # Avoid repeatedly polling empty log entry. Sleep here to give loki server a break.
+                    time.sleep(1)
+                else:
+                    break
+
+            # Update the params for updated range.
+            start_timestamp_ns += 1  # Start time should exclude the previous entries.
+            if should_follow:  # end time should only be updated when we are following.
+                end_timestamp_ns = int(time.time() * 1e9)
