@@ -9,27 +9,19 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 import click
 import yaml
 
-from anyscale.autosync_heartbeat import (
-    get_working_dir_host_mount_location,
-    managed_autosync_session,
-    perform_autopush_synchronization,
-    perform_sync,
-)
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client import (
     AppConfig,
     Build,
     ComputeTemplateConfig,
     CreateComputeTemplate,
-    CreateSessionFromSnapshotOptions,
     Session,
-    SessionState,
     SessionUpOptions,
     SetupInitializeSessionOptions,
     StopSessionOptions,
 )
 from anyscale.cloud import get_cloud_id_and_name
-from anyscale.cluster_config import (
+from anyscale.cluster_config import (  # pylint:disable=private-import
     _configure_min_max_workers,
     _update_file_mounts,
     get_cluster_config,
@@ -376,33 +368,6 @@ class SessionController(BaseController):
                 f"Terminating session {session_name} due to keyboard interrupt."
             )
 
-    def fork_session(
-        self,
-        session_name: str,
-        new_session_name: str,
-        project_name: Optional[str] = None,
-    ) -> str:
-        source_session = self._resolve_session(session_name, project_name)
-        if source_session.state == SessionState.RUNNING:
-            self.log.warning(
-                "WARNING: Session is currently running, this may take several minutes."
-            )
-
-        project_url = get_endpoint(f"/projects/{source_session.project_id}")
-        self.log.info(
-            f"Forking session {session_name} into {new_session_name}. You can view its progress at {project_url}"
-        )
-        cloned_session = self._fork_session_internal(source_session, new_session_name)
-        self.log.info(f"Session {session_name} forked.")
-
-        wait_for_session_start(
-            cloned_session.project_id, cloned_session.name, self.api_client
-        )
-        url = get_endpoint(
-            f"/projects/{cloned_session.project_id}/clusters/{cloned_session.id}"
-        )
-        return f"Session {cloned_session.name} started. View at {url}"
-
     def ssh(
         self,
         session_name: str,
@@ -527,102 +492,6 @@ class SessionController(BaseController):
 
         subprocess.run(ssh_command)  # noqa: B1
 
-    def autopush(
-        self,
-        session_name: Optional[str] = None,
-        verbose: bool = False,
-        delete: bool = False,
-        ignore_errors: bool = False,
-    ) -> None:
-        message = (
-            "Warning: `anyscale autopush` is now deprecated as we encourage users to start "
-            'clusters with ray.init("anyscale://cluster_name") and runtime environments. '
-            "`anyscale autopush` will still work for the time being for clusters started "
-            "with the sdk, but we will remove it around the end of Q3. Please refer to "
-            "https://docs.anyscale.com/api-sdk-reference/anyscale-ray-client "
-            "to learn more about using ray.init() and let the Anyscale team know if you "
-            "are running into any issues."
-        )
-        print("\033[91m{}\033[00m".format(message), file=sys.stderr)
-
-        project_definition = load_project_or_throw()
-        project_id = get_project_id(project_definition.root)
-        print(f"Active project: {project_definition.root}\n")
-
-        session = get_project_session(project_id, session_name, self.api_client)
-
-        wait_for_session_start(project_id, session.name, self.api_client)
-
-        cluster_config = get_cluster_config(session_name, self.api_client)
-
-        rsync_exclude = cluster_config.get("rsync_exclude") or []
-        rsync_filter = cluster_config.get("rsync_filter") or []
-
-        head_ip = self.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get(
-            session.id
-        ).result.head_ip
-        ssh_user = cluster_config["auth"]["ssh_user"]
-        ssh_private_key_path = cluster_config["auth"]["ssh_private_key"]
-
-        ssh_command = [
-            "ssh",
-            "-o",
-            "StrictHostKeyChecking=no",
-            "-o",
-            "UserKnownHostsFile={}".format(os.devnull),
-            "-o",
-            "LogLevel=ERROR",
-            "-i",
-            ssh_private_key_path,
-        ]
-        source = project_definition.root
-        target = get_working_dir(cluster_config, project_id, self.api_client)
-        if bool(get_container_name(cluster_config)):
-            target = get_working_dir_host_mount_location(
-                ssh_command,
-                ssh_user,
-                head_ip,
-                get_container_name(cluster_config),
-                target,
-            )
-
-        print("Autopush with session {} is starting up...".format(session.name))
-        with managed_autosync_session(session.id, self.api_client):
-            # Performing initial full synchronization with rsync.
-            first_sync = perform_sync(
-                ssh_command,
-                source,
-                ssh_user,
-                head_ip,
-                target,
-                delete,
-                rsync_filter=rsync_filter,
-                rsync_exclude=rsync_exclude,
-            )  # noqa: B1
-
-            if first_sync.returncode != 0:
-                message = f"First sync failed with error code: {first_sync.returncode}."
-                if ignore_errors:
-                    print(
-                        f'{message} Continuing to sync due to "--ignore-error" option.'
-                    )
-                else:
-                    raise click.ClickException(
-                        f"{message} If you would like to continue syncing, please use "
-                        'autopush with "--ignore-error" option.'
-                    )
-
-            perform_autopush_synchronization(
-                ssh_command,
-                source,
-                ssh_user,
-                head_ip,
-                target,
-                delete=delete,
-                rsync_filter=rsync_filter,
-                rsync_exclude=rsync_exclude,
-            )
-
     def pull(
         self,
         session_name: Optional[str] = None,
@@ -955,32 +824,3 @@ class SessionController(BaseController):
             )
 
         return sessions_list[0]
-
-    def _fork_session_internal(
-        self, source_session: Session, new_session_name: str
-    ) -> Session:
-        """
-        Creates a clone of the source session.
-        Raises an exception if cloning fails.
-
-        Params
-        source_session - session to clone
-        new_session_name - name of the new session
-        """
-        self.api_client.fork_session_api_v2_sessions_session_id_fork_post(
-            session_id=source_session.id,
-            create_session_from_snapshot_options=CreateSessionFromSnapshotOptions(
-                project_id=source_session.project_id, name=new_session_name
-            ),
-            # forking an active session can take up to 180s
-            _request_timeout=300000,
-        )
-
-        forked_sessions_list = self.api_client.list_sessions_api_v2_sessions_get(
-            project_id=source_session.project_id, name=new_session_name
-        ).results
-
-        if len(forked_sessions_list) == 0:
-            raise click.ClickException("Unable to fork session.")
-
-        return forked_sessions_list[0]
