@@ -6,15 +6,16 @@ from click import ClickException
 import yaml
 
 import anyscale
-from anyscale.api import get_api_client
-from anyscale.cli_logger import _CliLogger
+from anyscale.authenticate import get_auth_api_client
+from anyscale.cli_logger import BlockLogger
+from anyscale.client.openapi_client import Project
 from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.shared_anyscale_utils.util import slugify
 from anyscale.util import get_endpoint, send_json_request
 
 
 ANYSCALE_PROJECT_FILE = ".anyscale.yaml"
-log = _CliLogger()
+log = BlockLogger()
 
 
 def find_project_root(directory: str) -> Optional[str]:
@@ -72,7 +73,7 @@ def get_project_id(project_dir: str) -> str:
         # they were trying to run.
         raise ClickException(
             "Ray project in {} not registered yet. "
-            "Did you run 'anyscale init'?".format(project_dir)
+            "Did you run 'anyscale project init'?".format(project_dir)
         )
     try:
         result = str(project_id)
@@ -95,9 +96,9 @@ def get_project_sessions(
     all_active_states: bool = False,
 ) -> Any:
     """
-    Returns active project sessions. If `all_active_states` is set, returns sessions with
+    Returns active project clusters. If `all_active_states` is set, returns clusters with
         the following states: StartingUp, _StartingUp, StartupErrored, Running, Updating,
-        UpdatingErrored, AwaitingFileMounts. Otherwise, only return sessions in the
+        UpdatingErrored, AwaitingFileMounts. Otherwise, only return clusters in the
         Running and AwaitingFileMounts state.
     """
     if api_client is None:
@@ -120,7 +121,7 @@ def get_project_sessions(
     sessions = response.results
     if len(sessions) == 0:
         raise ClickException(
-            "No active session matching pattern {} found".format(session_name)
+            "No active cluster matching pattern {} found".format(session_name)
         )
     return sessions
 
@@ -134,7 +135,7 @@ def _get_project_sessions(project_id: str, session_name: Optional[str]) -> Any:
     sessions = response["results"]
     if len(sessions) == 0:
         raise ClickException(
-            "No active session matching pattern {} found".format(session_name)
+            "No active cluster matching pattern {} found".format(session_name)
         )
     return sessions
 
@@ -148,7 +149,7 @@ def get_project_session(
     sessions = get_project_sessions(project_id, session_name, api_client)
     if len(sessions) > 1:
         raise ClickException(
-            "Multiple active sessions: {}\n"
+            "Multiple active clusters: {}\n"
             "Please specify the one you want to refer to.".format(
                 [session.name for session in sessions]
             )
@@ -161,7 +162,7 @@ def _get_project_session(project_id: str, session_name: Optional[str]) -> Any:
     sessions = get_project_sessions(project_id, session_name)
     if len(sessions) > 1:
         raise ClickException(
-            "Multiple active sessions: {}\n"
+            "Multiple active clusters: {}\n"
             "Please specify the one you want to refer to.".format(
                 [session["name"] for session in sessions]
             )
@@ -176,7 +177,7 @@ def get_proj_name_from_id(project_id: str, api_client: DefaultApi) -> str:
 
     if resp is None:
         raise ClickException(
-            "This local project is not registered with anyscale. Please re-run `anyscale init`."
+            "This local project is not registered with anyscale. Please re-run `anyscale project init`."
         )
     else:
         return str(resp.result.name)
@@ -188,7 +189,7 @@ def get_proj_id_from_name(
     owner: Optional[str] = None,  # this can be the email or the username of the owner
 ) -> str:
     if api_client is None:
-        api_client = get_api_client()
+        api_client = get_auth_api_client().api_client
 
     resp = api_client.find_project_by_project_name_api_v2_projects_find_by_name_get(
         name=project_name, _request_timeout=30, owner=owner
@@ -197,7 +198,7 @@ def get_proj_id_from_name(
     if not resp.results:
         raise ClickException(
             f"There is no project '{project_name}' that is registered with Anyscale. "
-            "View the registered projects with `anyscale list projects`."
+            "View the registered projects with `anyscale project list`."
         )
 
     projects = resp.results
@@ -219,7 +220,7 @@ def get_proj_id_from_name(
     else:
         raise ClickException(
             f"There are multiple projects '{project_name}' registered with Anyscale. "
-            "View the registered projects with `anyscale list projects`."
+            "View the registered projects with `anyscale project list`."
             "Please specify the --owner flag to specify an alternate owner"
         )
 
@@ -233,48 +234,18 @@ def _write_project_file_to_disk(project_id: str, directory: str) -> None:
 
 
 def create_new_proj_def(
-    name: Optional[str], api_client: DefaultApi = None,
+    name: str, api_client: DefaultApi = None,
 ) -> Tuple[str, ProjectDefinition]:
-    project_name = ""
-    if not name:
-        while project_name == "":
-            project_name = click.prompt("Project name", type=str)
-            if not validate_project_name(project_name):
-                log.info(
-                    '"{}" contains spaces. Please enter a project name without spaces'.format(
-                        project_name
-                    )
-                )
-                project_name = ""
-    else:
-        project_name = str(name)
-    if slugify(project_name) != project_name:
-        project_name = slugify(project_name)
-        log.info("Normalized project name to {}".format(project_name))
+    if slugify(name) != name:
+        name = slugify(name)
+        log.info("Normalized project name to {}".format(name))
 
     project_definition = anyscale.project.ProjectDefinition(os.getcwd())
-    project_definition.config["name"] = project_name
-    return project_name, project_definition
+    project_definition.config["name"] = name
+    return name, project_definition
 
 
-def register_project(
-    project_definition: ProjectDefinition, api_client: DefaultApi
-) -> None:
-
-    project_name = project_definition.config["name"]
-    description = project_definition.config.get("description", "")
-
-    # Add a database entry for the new Project.
-    resp = api_client.create_project_api_v2_projects_post(
-        write_project={
-            "name": project_name,
-            "description": description,
-            "initial_cluster_config": None,
-        }
-    )
-    result = resp.result
-    project_id = result.id
-
+def _do_attach(project_id: str, is_create_project: bool) -> None:
     with open(anyscale.project.ANYSCALE_PROJECT_FILE, "w") as f:
         yaml.dump(
             {"project_id": project_id}, f,
@@ -282,4 +253,81 @@ def register_project(
 
     # Print success message
     url = get_endpoint(f"/projects/{project_id}")
-    log.info(f"Project {project_id} created. View at {url}")
+    if is_create_project:
+        log.info(f"Project {project_id} created. View at {url}")
+    else:
+        log.info(f"Attached to project {project_id}. View at {url}")
+
+
+def register_or_attach_to_project(
+    project_definition: ProjectDefinition, api_client: DefaultApi
+) -> None:
+
+    project_name = project_definition.config["name"]
+    description = project_definition.config.get("description", "")
+
+    # Find if project with name already exists
+    existing_projects = api_client.find_project_by_project_name_api_v2_projects_find_by_name_get(
+        project_name
+    )
+    existing_project = None
+    if existing_projects:
+        if len(existing_projects.results) == 1:
+            existing_project = existing_projects.results[0]
+        elif len(existing_projects.results) > 1:
+            try:
+                user_info = api_client.get_user_info_api_v2_userinfo_get()
+            except Exception:
+                raise ClickException(
+                    f"More than one project with name {project_name} was found. Please connect to this project using --project-id parameter"
+                )
+
+            for project in existing_projects.results:
+                if project.creator_id == user_info.result.id:
+                    existing_project = project
+
+            if not existing_project:
+                raise ClickException(
+                    f"More than one project with name {project_name} was found. Please connect to this project using --project-id parameter"
+                )
+            else:
+                log.info(
+                    f"Multiple projects with name {project_name} was found. Connecting to the one created by you."
+                )
+
+    if not existing_project:
+        # Add a database entry for the new Project.
+        resp = api_client.create_project_api_v2_projects_post(
+            write_project={
+                "name": project_name,
+                "description": description,
+                "initial_cluster_config": None,
+            }
+        )
+        result = resp.result
+        project_id = result.id
+    else:
+        project_id = existing_project.id
+
+    _do_attach(project_id, not existing_project)
+
+
+def attach_to_project_with_id(project_id: str, api_client: DefaultApi) -> None:
+    validate_project_id(project_id, api_client)
+
+    _do_attach(project_id, False)
+
+
+def validate_project_id(project_id, api_client: DefaultApi) -> Project:
+    # Find if project with name already exists
+    try:
+        resp = api_client.get_project_api_v2_projects_project_id_get(project_id)
+    except Exception:
+        resp = None
+
+    if not resp:
+        raise click.ClickException(
+            f"Project with id {project_id} does not exist. Instead, you can provide a name to anyscale project init to create a new project."
+        )
+
+    return resp.result
