@@ -22,12 +22,8 @@ from anyscale.commands.project_commands import (
     anyscale_init,
     project_cli,
 )
-from anyscale.commands.run_commands import anyscale_kill_job, anyscale_run
 from anyscale.commands.service_commands import service_cli
 from anyscale.commands.session_commands import (
-    anyscale_autopush,
-    anyscale_autosync,
-    anyscale_fork,
     anyscale_pull,
     anyscale_push,
     anyscale_ssh,
@@ -130,15 +126,10 @@ cli.add_command(cluster_cli)
 cli.add_command(anyscale_init)
 cli.add_command(anyscale_up)
 cli.add_command(anyscale_stop)
-cli.add_command(anyscale_autosync)
-cli.add_command(anyscale_autopush)
-cli.add_command(anyscale_fork)
 cli.add_command(anyscale_clone)
 cli.add_command(anyscale_ssh)
 cli.add_command(anyscale_start)
 cli.add_command(anyscale_exec)
-cli.add_command(anyscale_run)
-cli.add_command(anyscale_kill_job)
 cli.add_command(anyscale_pull)
 cli.add_command(anyscale_push)
 cli.add_command(anyscale_help)
