@@ -787,15 +787,27 @@ def validate_non_negative_arg(ctx, param, value):
     return value
 
 
-def _update_external_ids_for_policy(policy: Dict[str, Any], new_external_id: str):
+def number_of_external_ids_in_policy(policy: Dict[str, Any]) -> int:
+    """Counts the number of External IDs in a given policy"""
+    external_ids = [
+        statement.get("Condition", {}).get("StringEquals", {}).get("sts:ExternalId", [])
+        for statement in policy.get("Statement", [])
+    ]
+    return sum(1 if isinstance(i, str) else len(i) for i in external_ids)
+
+
+def _update_external_ids_for_policy(
+    original_policy: Dict[str, Any], new_external_id: str
+):
     """Gets All External IDs From policy Dict."""
-    policy = deepcopy(policy)
+    policy = deepcopy(original_policy)
     external_ids = [
         statement.setdefault("Condition", {})
         .setdefault("StringEquals", {})
         .setdefault("sts:ExternalId", [])
         for statement in policy.get("Statement", [])
     ]
+
     external_ids = [
         [i, new_external_id] if isinstance(i, str) else i + [new_external_id]
         for i in external_ids
