@@ -1,4 +1,4 @@
-from typing import List, Optional, Tuple
+from typing import Any, Dict, Iterator, List, Optional, Tuple
 from unittest.mock import Mock, patch
 
 from click import ClickException
@@ -8,10 +8,10 @@ from anyscale.client.openapi_client.models import (
     AnyscaleAWSAccount,
     AnyscaleawsaccountResponse,
     Cloud,
+    CloudConfig,
     CloudResponse,
+    WriteCloud,
 )
-from anyscale.client.openapi_client.models.cloud_config import CloudConfig
-from anyscale.client.openapi_client.models.write_cloud import WriteCloud
 from anyscale.controllers.cloud_controller import CloudController
 
 
@@ -32,8 +32,10 @@ def mock_api_client(cloud_test_data: Cloud) -> Mock:
     return mock_api_client
 
 
-@pytest.fixture()
-def mock_auth_api_client(mock_api_client: Mock, base_mock_anyscale_api_client: Mock):
+@pytest.fixture(autouse=True)
+def mock_auth_api_client(
+    mock_api_client: Mock, base_mock_anyscale_api_client: Mock
+) -> Iterator[None]:
     mock_auth_api_client = Mock(
         api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client,
     )
@@ -44,24 +46,41 @@ def mock_auth_api_client(mock_api_client: Mock, base_mock_anyscale_api_client: M
         yield
 
 
-def mock_role() -> Mock:
+@pytest.fixture(autouse=True)
+def mock_get_available_regions() -> Iterator[None]:
+    with patch(
+        "anyscale.controllers.cloud_controller.get_available_regions",
+        return_value=["us-west-2"],
+        autospec=True,
+    ):
+        yield
+
+
+def mock_role(document: Optional[Dict[str, Any]] = None) -> Mock:
+    if document is None:
+        document = {}
     mock_role = Mock()
 
     mock_role.arn = "ARN"
     mock_role.attach_policy = Mock()
-    mock_role.assume_role_policy_document = {}
+    mock_role.assume_role_policy_document = document
 
     return mock_role
 
 
 @pytest.mark.parametrize("region", ["mock-region", None])
-def test_setup_cloud_aioa(mock_auth_api_client, region: Optional[str]) -> None:
+def test_setup_cloud_aioa(region: Optional[str]) -> None:
 
     expected_region = region or "us-west-2"
 
     cloud_controller = CloudController()
     cloud_controller.setup_cloud(
-        is_aioa=True, provider="aws", region=region, name="test-aioa", yes=True
+        is_aioa=True,
+        is_k8s=True,
+        provider="aws",
+        region=region,
+        name="test-aioa",
+        yes=True,
     )
     cloud_controller.api_client.create_cloud_api_v2_clouds_post.assert_called_once_with(
         write_cloud=WriteCloud(
@@ -75,23 +94,33 @@ def test_setup_cloud_aioa(mock_auth_api_client, region: Optional[str]) -> None:
     )
 
 
-def test_setup_cloud_aioa_invalid(mock_auth_api_client) -> None:
+def test_setup_cloud_aioa_invalid() -> None:
 
     cloud_controller = CloudController()
     with pytest.raises(ClickException):
         cloud_controller.setup_cloud(
-            is_aioa=True, provider="gcp", region="us-west1", name="test-aioa", yes=True
+            is_aioa=True,
+            is_k8s=True,
+            provider="gcp",
+            region="us-west1",
+            name="test-aioa",
+            yes=True,
         )
     cloud_controller.api_client.create_cloud_api_v2_clouds_post.assert_not_called()
 
 
-def test_setup_cloud_aws(mock_auth_api_client) -> None:
+def test_setup_cloud_aws() -> None:
     with patch.object(
         CloudController, "setup_aws", return_value=None
     ) as mock_setup_aws:
         cloud_controller = CloudController()
         cloud_controller.setup_cloud(
-            is_aioa=False, provider="aws", region=None, name="test-aws", yes=False
+            is_aioa=False,
+            is_k8s=False,
+            provider="aws",
+            region=None,
+            name="test-aws",
+            yes=False,
         )
 
         mock_setup_aws.assert_called_once_with(
@@ -99,7 +128,26 @@ def test_setup_cloud_aws(mock_auth_api_client) -> None:
         )
 
 
-def test_setup_cloud_gcp(mock_auth_api_client) -> None:
+def test_setup_cloud_aws_k8s() -> None:
+    with patch.object(
+        CloudController, "setup_aws_k8s_cloud", return_value=None
+    ) as mock_setup_aws_k8s_cloud:
+        cloud_controller = CloudController()
+        cloud_controller.setup_cloud(
+            is_aioa=False,
+            is_k8s=True,
+            provider="aws",
+            region=None,
+            name="test-aws",
+            yes=False,
+        )
+
+        mock_setup_aws_k8s_cloud.assert_called_once_with(
+            region="us-west-2", name="test-aws", yes=False
+        )
+
+
+def test_setup_cloud_gcp() -> None:
     mock_launch_gcp_cloud_setup = Mock(return_value=None)
     with patch.multiple(
         "anyscale.controllers.cloud_controller",
@@ -107,7 +155,12 @@ def test_setup_cloud_gcp(mock_auth_api_client) -> None:
     ):
         cloud_controller = CloudController()
         cloud_controller.setup_cloud(
-            is_aioa=False, provider="gcp", region=None, name="test-gcp", yes=True
+            is_aioa=False,
+            is_k8s=True,
+            provider="gcp",
+            region=None,
+            name="test-gcp",
+            yes=True,
         )
 
         mock_launch_gcp_cloud_setup.assert_called_once_with(
@@ -123,6 +176,7 @@ def test_setup_cloud_gcp(mock_auth_api_client) -> None:
 
         cloud_controller.setup_cloud(
             is_aioa=False,
+            is_k8s=True,
             provider="gcp",
             region=None,
             name="test-gcp",
@@ -148,7 +202,9 @@ def test_setup_cloud_gcp(mock_auth_api_client) -> None:
         ("10.0.0.0/12", "project_id", None),
     ],
 )
-def test_setup_cloud_gcp_vpc_peering(mock_auth_api_client, vpc_peering_options) -> None:
+def test_setup_cloud_gcp_vpc_peering(
+    vpc_peering_options: Tuple[str, Optional[str], Optional[str]]
+) -> None:
     (
         vpc_peering_ip_range,
         vpc_peering_target_project_id,
@@ -164,6 +220,7 @@ def test_setup_cloud_gcp_vpc_peering(mock_auth_api_client, vpc_peering_options)
             with pytest.raises(ClickException):
                 cloud_controller.setup_cloud(
                     is_aioa=False,
+                    is_k8s=True,
                     provider="gcp",
                     region=None,
                     name="test-gcp",
@@ -175,6 +232,7 @@ def test_setup_cloud_gcp_vpc_peering(mock_auth_api_client, vpc_peering_options)
         else:
             cloud_controller.setup_cloud(
                 is_aioa=False,
+                is_k8s=True,
                 provider="gcp",
                 region=None,
                 name="test-gcp",
@@ -200,6 +258,7 @@ def test_setup_cloud_gcp_vpc_peering(mock_auth_api_client, vpc_peering_options)
 
         cloud_controller.setup_cloud(
             is_aioa=False,
+            is_k8s=True,
             provider="gcp",
             region=None,
             name="test-gcp",
@@ -238,7 +297,7 @@ def test_setup_cloud_gcp_vpc_peering(mock_auth_api_client, vpc_peering_options)
     ],
 )
 def test_setup_cloud_gcp_vpc_peering_validation(
-    mock_auth_api_client, vpc_peering_options: Tuple[str, str, str], error_output: str
+    vpc_peering_options: Tuple[str, str, str], error_output: str
 ) -> None:
     (
         vpc_peering_ip_range,
@@ -255,6 +314,7 @@ def test_setup_cloud_gcp_vpc_peering_validation(
         with pytest.raises(ClickException) as e:
             cloud_controller.setup_cloud(
                 is_aioa=False,
+                is_k8s=True,
                 provider="gcp",
                 region=None,
                 name="test-gcp",
@@ -267,7 +327,7 @@ def test_setup_cloud_gcp_vpc_peering_validation(
         assert error_output in e.value.message
 
 
-def test_setup_cloud_gcp_bad_region(mock_auth_api_client) -> None:
+def test_setup_cloud_gcp_bad_region() -> None:
     mock_confirm = Mock(side_effect=ClickException("aborted"))
     with patch.multiple(
         "anyscale.controllers.cloud_controller", confirm=mock_confirm,
@@ -276,18 +336,24 @@ def test_setup_cloud_gcp_bad_region(mock_auth_api_client) -> None:
         # NOTE: GCP regions are [cont]-[local][number], not [cont]-[local]-[number]
         with pytest.raises(ClickException):
             cloud_controller.setup_cloud(
-                is_aioa=False, provider="gcp", region="us-west-2", name="test-gcp"
+                is_aioa=False,
+                is_k8s=True,
+                provider="gcp",
+                region="us-west-2",
+                name="test-gcp",
             )
 
         mock_confirm.assert_called()
 
 
 @pytest.mark.parametrize("is_aioa", [True, False])
-def test_setup_cloud_invalid_provider(mock_auth_api_client, is_aioa: bool) -> None:
+@pytest.mark.parametrize("is_k8s", [True, False])
+def test_setup_cloud_invalid_provider(is_aioa: bool, is_k8s: bool) -> None:
     cloud_controller = CloudController()
     with pytest.raises(ClickException):
         cloud_controller.setup_cloud(
             is_aioa=is_aioa,
+            is_k8s=is_k8s,
             provider="azure",
             region="azure-west-1",
             name="invalid cloud provider",
@@ -295,7 +361,7 @@ def test_setup_cloud_invalid_provider(mock_auth_api_client, is_aioa: bool) -> No
         )
 
 
-def test_delete_cloud_by_name(cloud_test_data: Cloud, mock_auth_api_client) -> None:
+def test_delete_cloud_by_name(cloud_test_data: Cloud) -> None:
     cloud_controller = CloudController()
     success = cloud_controller.delete_cloud(
         cloud_id=None, cloud_name=cloud_test_data.name, skip_confirmation=True
@@ -310,7 +376,7 @@ def test_delete_cloud_by_name(cloud_test_data: Cloud, mock_auth_api_client) -> N
     )
 
 
-def test_delete_cloud_by_id(cloud_test_data: Cloud, mock_auth_api_client) -> None:
+def test_delete_cloud_by_id(cloud_test_data: Cloud) -> None:
     cloud_controller = CloudController()
     success = cloud_controller.delete_cloud(
         cloud_id=cloud_test_data.id, cloud_name=None, skip_confirmation=True
@@ -325,7 +391,7 @@ def test_delete_cloud_by_id(cloud_test_data: Cloud, mock_auth_api_client) -> Non
     )
 
 
-def test_missing_name_and_id(mock_auth_api_client) -> None:
+def test_missing_name_and_id() -> None:
     cloud_controller = CloudController()
 
     with pytest.raises(ClickException):
@@ -338,14 +404,27 @@ def test_missing_name_and_id(mock_auth_api_client) -> None:
         cloud_controller.get_cloud_config(None, None)
 
 
-def test_setup_cross_region(mock_auth_api_client, cloud_test_data: Cloud) -> None:
+def test_setup_cross_region(cloud_test_data: Cloud) -> None:
     mock_get_aws_account = Mock(
         return_value=AnyscaleawsaccountResponse(
             result=AnyscaleAWSAccount(anyscale_aws_account="aws_account_type")
         )
     )
     mock_create_cloud = Mock(return_value=CloudResponse(result=cloud_test_data))
-    mocked_role = mock_role()
+    mocked_role = mock_role(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Sid": "1",
+                    "Effect": "Allow",
+                    "Principal": {"AWS": ["ARN"]},
+                    "Action": "sts:AssumeRole",
+                    "Condition": {"StringEquals": {"sts:ExternalId": "extid"}},
+                }
+            ],
+        }
+    )
 
     with patch.multiple(
         "anyscale.controllers.cloud_controller",
@@ -370,7 +449,7 @@ def test_setup_cross_region(mock_auth_api_client, cloud_test_data: Cloud) -> Non
         pytest.param([mock_role()], id="role_already_exists"),
     ],
 )
-def test_setup_aws_ray_role(mock_auth_api_client, roles: List[Optional[Mock]]) -> None:
+def test_setup_aws_ray_role(roles: List[Optional[Mock]]) -> None:
     assert roles[-1] is not None, "roles must end with a real role"
 
     mock_iam = Mock()
@@ -396,9 +475,7 @@ def test_setup_aws_ray_role(mock_auth_api_client, roles: List[Optional[Mock]]) -
     roles[-1].Policy().put.assert_called()
 
 
-def test_update_cloud_config_by_name(
-    cloud_test_data: Cloud, mock_auth_api_client
-) -> None:
+def test_update_cloud_config_by_name(cloud_test_data: Cloud) -> None:
     cloud_controller = CloudController()
     cloud_controller.update_cloud_config(
         cloud_id=None, cloud_name=cloud_test_data.name, max_stopped_instances=100,
@@ -413,9 +490,7 @@ def test_update_cloud_config_by_name(
     )
 
 
-def test_update_cloud_config_by_id(
-    cloud_test_data: Cloud, mock_auth_api_client
-) -> None:
+def test_update_cloud_config_by_id(cloud_test_data: Cloud) -> None:
     cloud_controller = CloudController()
     cloud_controller.update_cloud_config(
         cloud_id=cloud_test_data.id, cloud_name=None, max_stopped_instances=100,
@@ -429,9 +504,7 @@ def test_update_cloud_config_by_id(
 
 @pytest.mark.parametrize("cloud_id", [None, "cloud_id_1"])
 @pytest.mark.parametrize("cloud_name", [None, "cloud_name_1"])
-def test_set_default_cloud(
-    mock_auth_api_client, cloud_id: Optional[str], cloud_name: Optional[str]
-) -> None:
+def test_set_default_cloud(cloud_id: Optional[str], cloud_name: Optional[str]) -> None:
     cloud_controller = CloudController()
     if not (cloud_id or cloud_name) or (cloud_id and cloud_name):
         # Error if neither or both of cloud_id and cloud_name provided
@@ -450,9 +523,7 @@ def test_set_default_cloud(
 
 @pytest.mark.parametrize("cloud_id", [None, "cloud_id_1"])
 @pytest.mark.parametrize("cloud_name", [None, "cloud_name_1"])
-def test_list_cloud(
-    mock_auth_api_client, cloud_id: Optional[str], cloud_name: Optional[str]
-) -> None:
+def test_list_cloud(cloud_id: Optional[str], cloud_name: Optional[str]) -> None:
     cloud_controller = CloudController()
     cloud_controller.api_client.list_clouds_api_v2_clouds_get = Mock(
         return_value=Mock(results=[Mock()])
