@@ -277,3 +277,24 @@ def test_list(mock_auth_api_client, name: str, json_format: bool, any_creator: b
         assert projects_query.creator_id.equals == mock_creator_id
     assert projects_query.paging.count == 20
     assert projects_query.paging.paging_token is None
+
+
+@pytest.mark.parametrize("existing_projects", [[], [Mock()]])
+def test_create_project(mock_auth_api_client, existing_projects) -> None:
+    project_controller = ProjectController()
+    project_controller.api_client.find_project_by_project_name_api_v2_projects_find_by_name_get = Mock(
+        return_value=Mock(results=existing_projects)
+    )
+
+    project_controller.create("proj_name")
+
+    if existing_projects:
+        project_controller.api_client.create_project_api_v2_projects_post.assert_not_called()
+    else:
+        project_controller.api_client.create_project_api_v2_projects_post.assert_called_once_with(
+            write_project={
+                "name": "proj_name",
+                "description": "",
+                "initial_cluster_config": None,
+            }
+        )
